pub trait ToStatement: Sealed { }Expand description
A trait abstracting over prepared and unprepared statements.
Many methods are generic over this bound, so that they support both a raw query string as well as a statement which was prepared previously.
This trait is “sealed” and cannot be implemented by anything outside this crate.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".